==> huaweicloudsdkgeip-3.1.133-py2.py3-none-any.whl: huaweicloudsdkgeip/v3/model/resources_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResourcesInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'used': 'int',
        'quota': 'int',
        'min': 'int'
    }

    attribute_map = {
        'type': 'type',
        'used': 'used',
        'quota': 'quota',
        'min': 'min'
    }

    def __init__(self, type=None, used=None, quota=None, min=None):
        """ResourcesInfo

        The model defined in huaweicloud sdk

        :param type: 配额类型
        :type type: str
        :param used: 已使用配额
        :type used: int
        :param quota: 总配额数
        :type quota: int
        :param min: 最小配额值
        :type min: int
        """
        
        

        self._type = None
        self._used = None
        self._quota = None
        self._min = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if used is not None:
            self.used = used
        if quota is not None:
            self.quota = quota
        if min is not None:
            self.min = min

    @property
    def type(self):
        """Gets the type of this ResourcesInfo.

        配额类型

        :return: The type of this ResourcesInfo.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResourcesInfo.

        配额类型

        :param type: The type of this ResourcesInfo.
        :type type: str
        """
        self._type = type

    @property
    def used(self):
        """Gets the used of this ResourcesInfo.

        已使用配额

        :return: The used of this ResourcesInfo.
        :rtype: int
        """
        return self._used

    @used.setter
    def used(self, used):
        """Sets the used of this ResourcesInfo.

        已使用配额

        :param used: The used of this ResourcesInfo.
        :type used: int
        """
        self._used = used

    @property
    def quota(self):
        """Gets the quota of this ResourcesInfo.

        总配额数

        :return: The quota of this ResourcesInfo.
        :rtype: int
        """
        return self._quota

    @quota.setter
    def quota(self, quota):
        """Sets the quota of this ResourcesInfo.

        总配额数

        :param quota: The quota of this ResourcesInfo.
        :type quota: int
        """
        self._quota = quota

    @property
    def min(self):
        """Gets the min of this ResourcesInfo.

        最小配额值

        :return: The min of this ResourcesInfo.
        :rtype: int
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this ResourcesInfo.

        最小配额值

        :param min: The min of this ResourcesInfo.
        :type min: int
        """
        self._min = min

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourcesInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgeip-3.1.143-py2.py3-none-any.whl: huaweicloudsdkgeip/v3/model/resources_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResourcesInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'used': 'int',
        'quota': 'int',
        'min': 'int'
    }

    attribute_map = {
        'type': 'type',
        'used': 'used',
        'quota': 'quota',
        'min': 'min'
    }

    def __init__(self, type=None, used=None, quota=None, min=None):
        r"""ResourcesInfo

        The model defined in huaweicloud sdk

        :param type: 配额类型
        :type type: str
        :param used: 已使用配额
        :type used: int
        :param quota: 总配额数
        :type quota: int
        :param min: 最小配额值
        :type min: int
        """
        
        

        self._type = None
        self._used = None
        self._quota = None
        self._min = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if used is not None:
            self.used = used
        if quota is not None:
            self.quota = quota
        if min is not None:
            self.min = min

    @property
    def type(self):
        r"""Gets the type of this ResourcesInfo.

        配额类型

        :return: The type of this ResourcesInfo.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this ResourcesInfo.

        配额类型

        :param type: The type of this ResourcesInfo.
        :type type: str
        """
        self._type = type

    @property
    def used(self):
        r"""Gets the used of this ResourcesInfo.

        已使用配额

        :return: The used of this ResourcesInfo.
        :rtype: int
        """
        return self._used

    @used.setter
    def used(self, used):
        r"""Sets the used of this ResourcesInfo.

        已使用配额

        :param used: The used of this ResourcesInfo.
        :type used: int
        """
        self._used = used

    @property
    def quota(self):
        r"""Gets the quota of this ResourcesInfo.

        总配额数

        :return: The quota of this ResourcesInfo.
        :rtype: int
        """
        return self._quota

    @quota.setter
    def quota(self, quota):
        r"""Sets the quota of this ResourcesInfo.

        总配额数

        :param quota: The quota of this ResourcesInfo.
        :type quota: int
        """
        self._quota = quota

    @property
    def min(self):
        r"""Gets the min of this ResourcesInfo.

        最小配额值

        :return: The min of this ResourcesInfo.
        :rtype: int
        """
        return self._min

    @min.setter
    def min(self, min):
        r"""Sets the min of this ResourcesInfo.

        最小配额值

        :param min: The min of this ResourcesInfo.
        :type min: int
        """
        self._min = min

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourcesInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
